@@ -47,7 +47,8 @@ class PointInTimeGridRayTracing(DAG):
     )
 
     bsdfs = Inputs.folder(
-        description='Folder containing any BSDF files needed for ray tracing.'
+        description='Folder containing any BSDF files needed for ray tracing.',
+        optional=True
     )
 
     @task(template=SplitGrid)
